"""Definitions of quadrature rules."""

from quadraturerules.rules.gauss_legendre import gauss_legendre
from quadraturerules.rules.gauss_lobatto_legendre import gauss_lobatto_legendre
from quadraturerules.rules.xiao_gimbutas import xiao_gimbutas
